@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: semigroups
-version: 0.8.3.2
-id: semigroups-0.8.3.2-08bd9e08e0f404cc4af18eab242e78de
+version: 0.9.2
+id: semigroups-0.9.2-51d976447c6408479cabc66ac9867fc6
 
 license: BSD3
 copyright: Copyright (C) 2011 Edward A. Kmett
@@ -17,24 +17,24 @@ category: Algebra, Data, Data Structures, Math
 author: Edward A. Kmett
 pkgpath: devel/hs-semigroups
 exposed: True
-exposed-modules: Data.Semigroup Data.List.NonEmpty Numeric.Natural
-                 Numeric.Natural.Internal
+exposed-modules: Data.Semigroup Data.List.NonEmpty
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/semigroups-0.8.3.2
-library-dirs: /usr/local/lib/ghc/semigroups-0.8.3.2
-hs-libraries: HSsemigroups-0.8.3.2
+import-dirs: /usr/local/lib/ghc/semigroups-0.9.2
+library-dirs: /usr/local/lib/ghc/semigroups-0.9.2
+hs-libraries: HSsemigroups-0.9.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
+depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
+         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
+         nats-0.1-aec08333f55fa44b719505dcb3893327
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-semigroups-0.8.3.2/html/semigroups.haddock
-haddock-html: /usr/local/share/doc/hs-semigroups-0.8.3.2/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-semigroups-0.9.2/html/semigroups.haddock
+haddock-html: /usr/local/share/doc/hs-semigroups-0.9.2/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
